@@ -5,7 +5,10 @@ from .member import Member
 class Interaction:
     def __init__(self, received):
         self.raw: dict = received
-        self.app_permissions: int = int(received["app_permissions"])
+        self.app_permissions: None | int = received.get("app_permissions", None)
+        if self.app_permissions is not None:
+            self.app_permissions = int(self.app_permissions)
+
         self.channel_id: int = int(received["channel_id"])
         self.id: int = int(received["id"])
         self.locale: str = received["locale"]
@@ -33,7 +36,7 @@ class Interaction:
                 self.used_by: None | User = User(received["member"]["user"])
             else:
                 self.used_by: None | User = User(received["user"])
-        
+
         elif self.interaction_type == 5: # modal submit
             self.modal_values: None | list[dict] = self.data["components"][0]["components"]   
 
